<?php

/**
 * @file
 * Rules hooks and callbacks for Signup Status Rules module.
 * We use the signup data type from Signup Rules module to get signup
 * statuses from the database instead of defining our own data type.
 */

/**
 * Implements hook_rules_event_info().
 *
 * @ingroup rules
 */
function signup_status_rules_rules_event_info() {
  $events = array();
  $events['signup_status_rules_event_status_insert'] = array(
    'label' => t('Signup status was created'),
    'module' => 'Signup Status',
    'arguments' => _signup_status_rules_event_arguments(),
    'help' => 'This event is triggered when the signup status of an individual signup has been created by the Signup Status module.',
  );
  $events['signup_status_rules_event_status_update'] = array(
    'label' => t('Signup status was updated'),
    'module' => 'Signup Status',
    'arguments' => _signup_status_rules_event_arguments(),
    'help' => 'This event is triggered when the signup status of an individual signup has been changed by the Signup Status module.',
  );
  $events['signup_status_rules_event_status_delete'] = array(
    'label' => t('Signup status was deleted'),
    'module' => 'Signup Status',
    'arguments' => _signup_status_rules_event_arguments(),
    'help' => 'This event is triggered when the signup status of an individual signup has been deleted by the Signup Status module.',
  );
  return $events;
}

/**
 * Helper function for providing event arguments.
 */
function _signup_status_rules_event_arguments() {
  return array(
    'user' => array('type' => 'user', 'label' => t('User who is signed up for content')),
    'node' => array('type' => 'node', 'label' => t('Content to which the user is signed up')),
    'signup' => array('type' => 'signup', 'label' => t('Signup data')),
  );
}

/**
 * Implements hook_rules_condition_info().
 *
 * @ingroup rules
 */
function signup_status_rules_rules_condition_info() {
  $conditions = array();
  $conditions['signup_status_rules_condition_status_has_value'] = array(
    'label' => t('Signup status has value'),
    'arguments' => array(
      'signup' => array('type' => 'signup', 'label' => t('Signup data')),
    ),
    'help' => t('Evaluates to TRUE if the unchanged signup status has the selected value.'),
    'module' => 'Signup Status',
  );
  return $conditions;
}

/**
 * Verifies that a status has a specific value.
 */
function signup_status_rules_condition_status_has_value($signup, $settings) {
  $status = db_result(db_query('SELECT status FROM {signup_log} WHERE sid = %d', $signup->sid));
  if ($status == $settings['signup_status']) {
    return TRUE;
  }
  return FALSE;
}

/**
 * Implements hook_rules_action_info().
 *
 * @ingroup rules
 */
function signup_status_rules_rules_action_info() {
  $actions = array();
  $actions['signup_status_rules_set_status'] = array(
    'label' => t('Set signup status'),
    'module' => 'Signup Status',
    'arguments' => array(
      'signup' => array('type' => 'signup', 'label' => t('Signup data')),
    ),
    'help' => 'This action alters the signup status of a signup.',
  );
  return $actions;
}
